@@ -1,3 +1,4 @@
+from typing import List
 from dotenv import load_dotenv
 import json
 import os
@@ -179,7 +180,7 @@ class Thing:
             "Property " + property_name_to_find + " was not found.")
         return None
 
-    def find_shared_properties(self, group = "*") -> [Property]:
+    def find_shared_properties(self, group = "*") -> List[Property]:
         """Search for properties that are accessible by the Thing.
 
         Args:
@@ -226,7 +227,7 @@ class Thing:
                 If media type property, the path to the file to upload. Defaults to None.
         """
         self.logger.data(prop)
-        if file_name is None and self.mqtt.is_connected:
+        if file_name is None and self.mqtt.is_connected():
             self.mqtt.update_property(prop, file_name=file_name)
         else:
             self.http.update_property(prop, file_name=file_name)
